@@ -278,6 +278,9 @@ UNRESERVED_KEYWORDS = [
     "UPDATE",
     "USE",
     "VALUES",
+    "VAR",
+    "VARIABLE",
+    "VARIANT",
     "VIEW",
     "VIEWS",
     "WRITE",
